package store;

import java.io.*;

/**
* This interface defines the methods that a class must implement
* in order to be stored in RMS using the methods of the StorableObject
* class.
* <p>$Id: Storable.java,v 1.1 2003/01/19 18:06:27 finson Exp $
*/
public interface Storable {
	/**
	* Write out the values of this object.  Note that if there are
	* fields in the super class that should be written also, then
	* this method should call super.writeFields(out) in addition
	* to doing the explicit output calls for its own fields.
	* @param out the DataOutputStream on which to write the data
	*/
	public void writeFields(DataOutputStream out) throws IOException;
	/**
	* Read in the values of this object.  Note that if there are
	* fields in the super class that should be read also, then
	* this method should call super.readFields(in) in addition
	* to doing the explicit input calls for its own fields.
	* @param in the DataInputStream from which to read the data
	*/
	public void readFields(DataInputStream in) throws IOException;
}
		

